@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -35,6 +35,10 @@ class Audio {
 		Mix_Music *music;
 
 	public:
+		char songtitle[128];
+		char songalbum[128];
+		char songartist[128];
+		int songlicense;
 
 		int output;
 		bool useSound, useMusic;
