@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -22,12 +22,13 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 Cutscene::Cutscene()
 {
-	strcpy(sprite, "");
-	strcpy(text, "");
+	sprite[0] = 0;
+	text[0] = 0;
 	waitTime = 0;
 }
 
 void Cutscene::appendText(const char *line)
 {
-	sprintf(text, "%s %s", text, line);
+	strlcat(text, " ", sizeof text);
+	strlcat(text, line, sizeof text);
 }
