@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -22,13 +22,13 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 Data::Data()
 {
-	strcpy(key, "");
-	strcpy(value, "");
+	key[0] = 0;
+	value[0] = 0;
 	current = 0;
 	target = 1;
 }
 
-void Data::set(char *key, char *value, int current, int target)
+void Data::set(const char *key, const char *value, int current, int target)
 {
 	if ((strlen(key) > 100) || (strlen(value) > 100))
 	{
@@ -36,8 +36,8 @@ void Data::set(char *key, char *value, int current, int target)
 		return;
 	}
 
-	strcpy(this->key, key);
-	strcpy(this->value, value);
+	strlcpy(this->key, key, sizeof this->key);
+	strlcpy(this->value, value, sizeof this->value);
 	this->current = current;
 	this->target = target;
 }
