@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -19,6 +19,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #include "headers.h"
+#include <errno.h>
 
 Engine::Engine()
 {
@@ -40,7 +41,7 @@ Engine::Engine()
 	
 	allowJoypad = true;
 
-	strcpy(lastKeyPressed, "");
+	lastKeyPressed[0] = 0;
 
 	fullScreen = 0;
 
@@ -54,7 +55,7 @@ Engine::Engine()
 
 	highlightedWidget = NULL;
 
-	strcpy(message, "");
+	message[0] = 0;
 	messageTime = -1;
 
 	// Development Stuff
@@ -64,7 +65,7 @@ Engine::Engine()
 	binaryBuffer = NULL;
 	#ifdef FRAMEWORK_SDL
 	char pakPath[PATH_MAX];
-	strncpy(pakPath, PAKFULLPATH, sizeof(pakPath));
+	strlcpy(pakPath, PAKFULLPATH, sizeof(pakPath));
 	if (CFBundleGetMainBundle() != NULL) {
 		CFURLRef pakURL = CFBundleCopyResourceURL(CFBundleGetMainBundle(), CFSTR(PAKNAME), NULL, NULL);
 		if (pakURL != NULL) {
@@ -84,12 +85,6 @@ Engine::Engine()
 
 	// Cheats
 	memset(lastKeyEvents, ' ', 25);
-	#if USEPAK
-		cheats = false;
-	#else
-		cheats = true;
-		cheats = false;
-	#endif
 	cheatHealth = cheatExtras = cheatFuel = cheatLevels = false;
 	cheatBlood = cheatInvulnerable = cheatReload = cheatSpeed = cheatSkipLevel = false;
 	
@@ -102,12 +97,10 @@ void Engine::destroy()
 	deleteWidgets();
 
 	debug(("engine: free databuffer\n"));
-	if (dataBuffer != NULL)
-		delete[] dataBuffer;
+	delete[] dataBuffer;
 
 	debug(("engine: free binarybuffer\n"));
-	if (binaryBuffer != NULL)
-		delete[] binaryBuffer;
+	delete[] binaryBuffer;
 
 	debug(("Clearing Define List...\n"));
 	defineList.clear();
@@ -151,7 +144,7 @@ void Engine::addKeyEvent()
 
 	if (index == -1)
 	{
-		for (int i = 0 ; i < 25 ; i++)
+		for (int i = 0 ; i < 24 ; i++)
 		{
 			lastKeyEvents[i] = lastKeyEvents[i + 1];
 		}
@@ -235,7 +228,7 @@ void Engine::getInput()
 				}
 
 				keyState[event.key.keysym.sym] = 1;
-				strcpy(lastKeyPressed, SDL_GetKeyName(event.key.keysym.sym));
+				strlcpy(lastKeyPressed, SDL_GetKeyName(event.key.keysym.sym), sizeof lastKeyPressed);
 				addKeyEvent();
 				break;
 
@@ -280,12 +273,12 @@ void Engine::getInput()
 	}
 }
 
-int Engine::getMouseX()
+int Engine::getMouseX() const
 {
 	return mouseX;
 }
 
-int Engine::getMouseY()
+int Engine::getMouseY() const
 {
 	return mouseY;
 }
@@ -320,7 +313,7 @@ void Engine::clearInput()
 
 void Engine::setUserHome(const char *path)
 {
-	strcpy(userHomeDirectory, path);
+	strlcpy(userHomeDirectory, path, sizeof userHomeDirectory);
 	debug(("User Home = %s\n", path));
 }
 
@@ -337,18 +330,16 @@ since SDL currently provides no means to load music directly from memory
 */
 bool Engine::unpack(const char *filename, int fileType)
 {
+	bool ret = true;
+
 	if (fileType == PAK_DATA)
 	{
-		if (dataBuffer != NULL)
-			delete[] dataBuffer;
-
+		delete[] dataBuffer;
 		dataBuffer = NULL;
 	}
 	else
 	{
-		if (binaryBuffer != NULL)
-			delete[] binaryBuffer;
-
+		delete[] binaryBuffer;
 		binaryBuffer = NULL;
 	}
 
@@ -377,7 +368,7 @@ bool Engine::unpack(const char *filename, int fileType)
 		}
 	}
 
-	if ((fileType == PAK_MUSIC) || (fileType == PAK_FONT))
+	if ((fileType == PAK_MUSIC) || (fileType == PAK_FONT) || (fileType == PAK_TAGS))
 	{
 		char tempPath[PATH_MAX];
 		
@@ -385,37 +376,47 @@ bool Engine::unpack(const char *filename, int fileType)
 
 		if (fileType == PAK_MUSIC)
 		{
-			sprintf(tempPath, "%smusic.mod", userHomeDirectory);
+			snprintf(tempPath, sizeof tempPath, "%smusic.mod", userHomeDirectory);
+			fp = fopen(tempPath, "wb");
+		}
+
+		if (fileType == PAK_TAGS)
+		{
+			snprintf(tempPath, sizeof tempPath, "%smusic.tags", userHomeDirectory);
 			fp = fopen(tempPath, "wb");
 		}
 
 		if (fileType == PAK_FONT)
 		{
-			sprintf(tempPath, "%sfont.ttf", userHomeDirectory);
+			snprintf(tempPath, sizeof tempPath, "%sfont.ttf", userHomeDirectory);
 			fp = fopen(tempPath, "wb");
 		}
 
 		if (!fp)
 		{
+			printf("Fatal Error: could not open %s for writing: %s", tempPath, strerror(errno));
 			return false;
 		}
 
-		fwrite(binaryBuffer, 1, pak.getUncompressedSize(), fp);
+		if (fwrite(binaryBuffer, 1, pak.getUncompressedSize(), fp) != pak.getUncompressedSize())
+		{
+			printf("Fatal Error: could not write to %s: %s", tempPath, strerror(errno));
+			ret = false;
+		}
 		fclose(fp);
 	}
 
-	debug(("unpack() : Loaded %s (%d)\n", filename, pak.getUncompressedSize()));
+	debug(("unpack() : Loaded %s (%d), ret: %d\n", filename, pak.getUncompressedSize(), (int)ret));
 
-	return true;
+	return ret;
 }
 
 bool Engine::loadData(const char *filename)
 {
-	if (dataBuffer != NULL)
-	{
-		delete[] dataBuffer;
-		dataBuffer = NULL;
-	}
+	bool ret = true;
+
+	delete[] dataBuffer;
+	dataBuffer = NULL;
 	
 	#if USEPAK
 		return unpack(filename, PAK_DATA);
@@ -432,15 +433,18 @@ bool Engine::loadData(const char *filename)
 
 	rewind(fp);
 
-	dataBuffer = new unsigned char[fSize];
+	dataBuffer = new unsigned char[fSize + 1];
 
-	fread(dataBuffer, 1, fSize, fp);
+	if (fread(dataBuffer, 1, fSize, fp) != (size_t)fSize)
+		ret = false;
+
+	dataBuffer[fSize] = 0;
 
 	fclose(fp);
 
-	debug(("loadData() : Loaded %s (%d)\n", filename, fSize));
+	debug(("loadData() : Loaded %s (%d), ret: %d\n", filename, fSize, (int)ret));
 
-	return true;
+	return ret;
 }
 
 void Engine::reportFontFailure()
@@ -463,7 +467,7 @@ void Engine::setPlayerPosition(int x, int y, int limitLeft, int limitRight, int
 	Math::limitInt(&playerPosY, limitUp, limitDown);
 }
 
-int Engine::getFrameLoop()
+int Engine::getFrameLoop() const
 {
 	return frameLoop;
 }
@@ -480,7 +484,7 @@ void Engine::doTimeDifference()
 	time2 = SDL_GetTicks();
 }
 
-float Engine::getTimeDifference()
+float Engine::getTimeDifference() const
 {
 	return timeDifference;
 }
@@ -494,7 +498,7 @@ void Engine::setInfoMessage(const char *message, int priority, int type)
 {
 	if (priority >= messagePriority)
 	{
-		strcpy(this->message, message);
+		strlcpy(this->message, message, sizeof this->message);
 		messageTime = 180;
 		messagePriority = priority;
 		messageType = type;
@@ -962,7 +966,7 @@ int Engine::getValueOfFlagTokens(const char *realLine)
 	char line[1024];
 	bool found;
 	int value;
-	strcpy(line, realLine);
+	strlcpy(line, realLine, sizeof line);
 
 	int flags = 0;
 
