@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -63,14 +63,14 @@ class Game {
 		void destroy();
 		void incrementMissionTime();
 		void setCheckPoint(float x, float y);
-		void getCheckPoint(float *x, float *y);
+		void getCheckPoint(float *x, float *y) const;
 		void setObjectiveCheckPoint();
 		void useObjectiveCheckPoint();
 		void doCombo();
 		void incBulletsFired();
 		void incBulletsHit();
 		int getWeaponAccuracy(int weapon);
-		int getTotalBulletsFired();
+		int getTotalBulletsFired() const;
 		int getTotalAccuracy();
 		int getMostUsedWeapon();
 		void totalUpStats();
