@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -83,14 +83,14 @@ void GameData::setMIARescueCount(const char *key, int rescues, int total)
 	Data *data = (Data*)dataList.getHead();
 
 	char newKey[100];
-	sprintf(newKey, "%s MIAs", key);
+	snprintf(newKey, sizeof newKey, "%s MIAs", key);
 
 	while (data->next != NULL)
 	{
 		data = (Data*)data->next;
 		if (strcmp(newKey, data->key) == 0)
 		{
-			strcpy(data->value, "MIAs");
+			strlcpy(data->value, "MIAs", sizeof data->value);
 			data->current = rescues;
 			data->target = total;
 			return;
@@ -109,7 +109,7 @@ bool GameData::MIARescued(const char *stageName, char *name)
 	Data *data = (Data*)dataList.getHead();
 
 	char newName[100];
-	sprintf(newName, "MIA_%s", name);
+	snprintf(newName, sizeof newName, "MIA_%s", name);
 
 	while (data->next != NULL)
 	{
