@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -31,6 +31,9 @@ Graphics::Graphics()
 	infoMessage = NULL;
 
 	fontSize = 0;
+	
+	medalMessageTimer = 0;
+	medalType = 0;
 
 	currentLoading = 0;
 
@@ -88,7 +91,11 @@ void Graphics::destroy()
 			TTF_CloseFont(font[i]);
 		}
 	}
-
+	
+	if (medalMessage != NULL)
+	{
+		SDL_FreeSurface(medalMessage);
+	}
 
 	if (fadeBlack)
 	{
@@ -99,6 +106,15 @@ void Graphics::destroy()
 	{
 		SDL_FreeSurface(infoBar);
 	}
+	
+	for (int i = 0 ; i < 4 ; i++)
+	{
+		if (medal[i] != NULL)
+		{
+			SDL_FreeSurface(medal[i]);
+			medal[i] = NULL;
+		}
+	}
 }
 
 void Graphics::registerEngine(Engine *engine)
@@ -129,6 +145,8 @@ void Graphics::mapColors()
 	fadeBlack = alphaRect(640, 480, 0x00, 0x00, 0x00);
 
 	infoBar = alphaRect(640, 25, 0x00, 0x00, 0x00);
+	
+	medalMessage = NULL;
 }
 
 Sprite *Graphics::getSpriteHead()
@@ -141,8 +159,34 @@ void Graphics::setTransparent(SDL_Surface *sprite)
 	SDL_SetColorKey(sprite, (SDL_SRCCOLORKEY|SDL_RLEACCEL), SDL_MapRGB(sprite->format, 0, 0, 0));
 }
 
+bool Graphics::canShowMedalMessage() const
+{
+	return (medalMessageTimer <= 0);
+}
+
 void Graphics::updateScreen()
 {
+	if (medalMessageTimer > 0)
+	{
+		int padding = 0;
+		
+		medalMessageTimer--;
+		
+		if (medalType >= 0)
+		{
+			padding = 18;
+		}
+		
+		drawRect(screen->w - (medalMessage->w + 5 + padding), 5, medalMessage->w + padding - 2, 20, grey, screen);
+		drawRect(screen->w - (medalMessage->w + 5 + padding - 1), 6, medalMessage->w + padding - 4, 18, black, screen);
+		blit(medalMessage, screen->w - (medalMessage->w + 5), 7, screen, false);
+		
+		if (medalType >= 0)
+		{
+			blit(medal[medalType], screen->w - (medalMessage->w + 5 + 16), 7, screen, false);
+		}
+	}
+	
 	SDL_Flip(screen);
 	SDL_Delay(1);
 
@@ -150,7 +194,7 @@ void Graphics::updateScreen()
 	{
 		if ((Math::prand() % 500) == 0)
 		{
-			sprintf(screenshot, "screenshots/screenshot%.3d.bmp", screenShotNumber);
+			snprintf(screenshot, sizeof screenshot, "screenshots/screenshot%.3d.bmp", screenShotNumber);
 			SDL_SaveBMP(screen, screenshot);
 			screenShotNumber++;
 		}
@@ -160,7 +204,7 @@ void Graphics::updateScreen()
 
 	if (engine->keyState[SDLK_F12])
 	{
-		sprintf(screenshot, "screenshots/screenshot%.3d.bmp", screenShotNumber);
+		snprintf(screenshot, sizeof screenshot, "screenshots/screenshot%.3d.bmp", screenShotNumber);
 		SDL_SaveBMP(screen, screenshot);
 		screenShotNumber++;
 
@@ -299,7 +343,7 @@ void Graphics::HSVtoRGB(float *r, float *g, float *b, float h, float s, float v)
 	}
 }
 
-SDL_Surface *Graphics::loadImage(const char *filename)
+SDL_Surface *Graphics::loadImage(const char *filename, bool srcalpha)
 {
 	SDL_Surface *image, *newImage;
 
@@ -326,7 +370,10 @@ SDL_Surface *Graphics::loadImage(const char *filename)
 		newImage = image;
 	}
 
-	setTransparent(newImage);
+	if(srcalpha)
+		SDL_SetAlpha(newImage, SDL_SRCALPHA, 255);
+	else
+		setTransparent(newImage);
 
 	return newImage;
 }
@@ -432,7 +479,7 @@ void Graphics::loadMapTiles(const char *baseDir)
 {
 	bool found, autoAlpha;
 	char filename[255];
-	strcpy(filename, "");
+	filename[0] = 0;
 
 	autoAlpha = false;
 	
@@ -449,7 +496,7 @@ void Graphics::loadMapTiles(const char *baseDir)
 	{
 		found = true;
 
-		sprintf(filename, "%s/%d.png", baseDir, i);
+		snprintf(filename, sizeof filename, "%s/%d.png", baseDir, i);
 
 		#if USEPAK
 		
@@ -507,7 +554,7 @@ void Graphics::loadFont(int i, const char *filename, int pixelSize)
 	
 	char tempPath[PATH_MAX];
 	
-	sprintf(tempPath, "%sfont.ttf", engine->userHomeDirectory);
+	snprintf(tempPath, sizeof tempPath, "%sfont.ttf", engine->userHomeDirectory);
 
 	bool found = false;
 	int size = 0;
@@ -569,7 +616,7 @@ void Graphics::loadFont(int i, const char *filename, int pixelSize)
 Sprite *Graphics::addSprite(const char *name)
 {
 	Sprite *sprite = new Sprite;
-	strcpy(sprite->name, name);
+	strlcpy(sprite->name, name, sizeof sprite->name);
 
 	spriteList.add(sprite);
 
@@ -615,17 +662,17 @@ void Graphics::animateSprites()
 	}
 }
 
-int Graphics::getWaterAnim()
+int Graphics::getWaterAnim() const
 {
 	return waterAnim;
 }
 
-int Graphics::getSlimeAnim()
+int Graphics::getSlimeAnim() const
 {
 	return slimeAnim;
 }
 
-int Graphics::getLavaAnim()
+int Graphics::getLavaAnim() const
 {
 	return lavaAnim;
 }
@@ -848,26 +895,59 @@ void Graphics::drawString(const char *in, int x, int y, int alignment, SDL_Surfa
 	SDL_Surface *text = TTF_RenderUTF8_Shaded(font[fontSize], in, fontForeground, fontBackground);
 
 	if (!text)
-	{
 		text = TTF_RenderUTF8_Shaded(font[fontSize], "FONT_ERROR", fontForeground, fontBackground);
-	}
+
+	if (!text)
+		return;
+
+	setTransparent(text);
 
 	if (alignment == TXT_RIGHT) x -= text->w;
 	if (alignment == TXT_CENTERED) center = true;
 
-	setTransparent(text);
 	blit(text, x, y, dest, center);
 	SDL_FreeSurface(text);
 }
 
+void Graphics::drawString(const char *in, int x, int y, int alignment, SDL_Surface *dest, SurfaceCache &cache)
+{
+	bool center = false;
+
+	if(!cache.text || strcmp(in, cache.text)) {
+		if(cache.surface)
+			SDL_FreeSurface(cache.surface);
+
+		if(cache.text)
+			::free(cache.text);
+
+		cache.text = strdup(in);
+
+		cache.surface = TTF_RenderUTF8_Shaded(font[fontSize], in, fontForeground, fontBackground);
+
+		if (!cache.surface)
+			cache.surface = TTF_RenderUTF8_Shaded(font[fontSize], "FONT_ERROR", fontForeground, fontBackground);
+
+		if(!cache.surface)
+			return;
+
+		setTransparent(cache.surface);
+	}
+
+	if (alignment == TXT_RIGHT) x -= cache.surface->w;
+	if (alignment == TXT_CENTERED) center = true;
+
+	blit(cache.surface, x, y, dest, center);
+}
+
 void Graphics::clearChatString()
 {
-	strcpy(chatString, "");
+	chatString[0] = 0;
 }
 
 void Graphics::createChatString(const char *in)
 {
-	sprintf(chatString, "%s %s", chatString, in);
+	strlcat(chatString, " ", sizeof chatString);
+	strlcat(chatString, in, sizeof chatString);
 }
 
 void Graphics::drawChatString(SDL_Surface *surface, int y)
@@ -903,7 +983,7 @@ void Graphics::drawChatString(SDL_Surface *surface, int y)
 			continue;
 		}
 
-		sprintf(wordWithSpace, "%s ", word);
+		snprintf(wordWithSpace, sizeof wordWithSpace, "%s ", word);
 
 		wordSurface = getString(wordWithSpace, false);
 
@@ -915,14 +995,62 @@ void Graphics::drawChatString(SDL_Surface *surface, int y)
 
 		blit(wordSurface, x, y, surface, false);
 
-		SDL_FreeSurface(wordSurface);
-
 		x += wordSurface->w;
 
+		SDL_FreeSurface(wordSurface);
+
 		word = strtok(NULL, " ");
 	}
 }
 
+void Graphics::showMedalMessage(int type, const char *in)
+{
+	char message[1024];
+	
+	if (medalMessage != NULL)
+	{
+		SDL_FreeSurface(medalMessage);
+	}
+	
+	setFontSize(0);
+	
+	switch (type)
+	{
+		// Bronze
+		case 1:
+			setFontColor(0xA6, 0x7D, 0x3D, 0x00, 0x00, 0x00);
+			break;
+		
+		// Silver
+		case 2:
+			setFontColor(0xC0, 0xC0, 0xC0, 0x00, 0x00, 0x00);
+			break;
+			
+		// Gold
+		case 3:
+			setFontColor(0xFF, 0xCC, 0x33, 0x00, 0x00, 0x00);
+			break;
+			
+		// Ruby
+		case 4:
+			setFontColor(0xFF, 0x11, 0x55, 0x00, 0x00, 0x00);
+			break;
+	}
+	
+	medalType = type - 1; // for indexing on the image
+	if (type != -1)
+	{
+		snprintf(message, sizeof message, "  Medal Earned - %s  ", in);
+		medalMessage = getString(message, true);
+	}
+	else
+	{
+		snprintf(message, sizeof message, "  %s  ", in);
+		medalMessage = getString(message, true);
+	}
+	medalMessageTimer = (5 * 60);
+}
+
 void Graphics::drawWidgetRect(int x, int y, int w, int h)
 {
 	drawRect(x - 5, y - 4, w + 10, h + 8, white, screen);
@@ -1044,7 +1172,7 @@ void Graphics::showErrorAndExit(const char *error, const char *param)
 	}
 
 	char message[256];
-	sprintf(message, error, param);
+	snprintf(message, sizeof message, error, param);
 
 	setFontSize(3); setFontColor(0xff, 0x00, 0x00, 0x00, 0x00, 0x00);
 	drawString("An unforseen error has occurred", 320, 50, true, screen);
