@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -22,8 +22,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 HubLevel::HubLevel()
 {
-	strcpy(stageName, "");
-	strcpy(filename, "");
+	stageName[0] = 0;
+	filename[0] = 0;
 	x = y = 0;
 
 	levelNameImage = NULL;
@@ -31,10 +31,10 @@ HubLevel::HubLevel()
 	next = NULL;
 }
 
-void HubLevel::set(char *stageName, char *filename, int x, int y)
+void HubLevel::set(const char *stageName, const char *filename, int x, int y)
 {
-	strcpy(this->stageName, stageName);
-	strcpy(this->filename, filename);
+	strlcpy(this->stageName, stageName, sizeof this->stageName);
+	strlcpy(this->filename, filename, sizeof this->filename);
 	this->x = x;
 	this->y = y;
 }
