@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -24,10 +24,8 @@ class Joystick {
 	
 		Joystick();
 	
-		int numberOfButtons;
+		int sensitivity;
 		
-		int left, right, up, down;
-		int fire, jump, jetpack;
-		int pause, map;
+		int control[CONTROL::MAX];
 
 };
