@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -27,20 +27,21 @@ Keyboard::Keyboard()
 
 void Keyboard::setDefaultKeys()
 {
-	left = SDLK_LEFT;
-	right = SDLK_RIGHT;
-	down = SDLK_DOWN;
-	fire = SDLK_LCTRL;
-	jump = SDLK_UP;
-	jetpack = SDLK_SPACE;
-	pause = SDLK_p;
-	map = SDLK_TAB;
+	control[CONTROL::LEFT] = SDLK_LEFT;
+	control[CONTROL::RIGHT] = SDLK_RIGHT;
+	control[CONTROL::DOWN] = SDLK_DOWN;
+	control[CONTROL::JUMP] = SDLK_UP;
+	control[CONTROL::UP] = 0;
+	control[CONTROL::FIRE] = SDLK_LCTRL;
+	control[CONTROL::JETPACK] = SDLK_SPACE;
+	control[CONTROL::PAUSE] = SDLK_p;
+	control[CONTROL::MAP] = SDLK_TAB;
 }
 
-char *Keyboard::translateKey(int key)
+const char *Keyboard::translateKey(int key)
 {
 	static char keyName[50];
-	strcpy(keyName, "");
+	keyName[0] = 0;
 	keyName[0] = '\0';
 	
 	if (key <= 0)
@@ -48,7 +49,7 @@ char *Keyboard::translateKey(int key)
 		return "...";
 	}
 	
-	strcpy(keyName, _(SDL_GetKeyName((SDLKey)key)));
+	strlcpy(keyName, _(SDL_GetKeyName((SDLKey)key)), sizeof keyName);
 	
 	/*
 	This is not really neccessary, but it just makes
