@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -22,8 +22,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 Objective::Objective()
 {
-	strcpy(this->description, "");
-	strcpy(this->target, "");
+	this->description[0] = 0;
+	this->target[0] = 0;
 	this->currentValue = 0;
 	this->targetValue = 0;
 	this->required = false;
@@ -34,8 +34,8 @@ Objective::Objective()
 
 Objective::Objective(const char *description, const char *target, int targetValue, bool required)
 {
-	strcpy(this->description, description);
-	strcpy(this->target, target);
+	strlcpy(this->description, description, sizeof this->description);
+	strlcpy(this->target, target, sizeof this->target);
 	this->targetValue = targetValue;
 	this->required = required;
 
