@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -30,6 +30,6 @@ class Objective : public GameObject {
 		bool completed;
 
 		Objective();
-		Objective(char *description, char *target, int targetValue, bool required);
+		Objective(const char *description, const char *target, int targetValue, bool required);
 
 };
