@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -39,9 +39,9 @@ class Pak {
 
 	Pak();
 	~Pak();
-	void setPakFile(char *pakFilename);
-	bool unpack(char *filename, unsigned char **buffer);
-	bool fileExists(char *filename);
-	unsigned int getUncompressedSize();
+	void setPakFile(const char *pakFilename);
+	bool unpack(const char *filename, unsigned char **buffer);
+	bool fileExists(const char *filename);
+	unsigned int getUncompressedSize() const;
 
 };
