@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -47,7 +47,7 @@ void Particle::setSprite(Sprite *sprite)
 
 	this->sprite = sprite;
 
-	currentFrame = rand() % (sprite->maxFrames + 1);
+	currentFrame = Math::prand() % (sprite->maxFrames + 1);
 	currentTime = 1;
 }
 
