@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -22,7 +22,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 Persistant::Persistant()
 {
-	strcpy(stageName, "");
+	stageName[0] = 0;
 	numberOfLines = 0;
 }
 
@@ -34,7 +34,7 @@ Persistant::~Persistant()
 
 void Persistant::setName(const char *name)
 {
-	strcpy(this->stageName, name);
+	strlcpy(this->stageName, name, sizeof this->stageName);
 }
 
 void Persistant::clear()
