@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -30,7 +30,7 @@ Trap::Trap()
 
 void Trap::setName(const char *name)
 {
-	strcpy(this->name, name);
+	strlcpy(this->name, name, sizeof this->name);
 }
 
 void Trap::setTrapType(int type)
