@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -22,7 +22,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 Weapon::Weapon()
 {
-	strcpy(name, "");
+	name[0] = 0;
 	id = 0;
 	damage = 0;
 	reload = 0;
@@ -32,12 +32,12 @@ Weapon::Weapon()
 	health = 0;
 }
 
-void Weapon::setName(char *name)
+void Weapon::setName(const char *name)
 {
-	strcpy(this->name, name);
+	strlcpy(this->name, name, sizeof this->name);
 }
 
-int Weapon::getSpeed(int face)
+int Weapon::getSpeed(int face) const
 {
 	return (dx - ((dx * 2) * face));
 }
