@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -22,10 +22,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 Widget::Widget()
 {
-	strcpy(name, "");
-	strcpy(groupName, "");
-	strcpy(label, "");
-	strcpy(options, "");
+	name[0] = 0;
+	groupName[0] = 0;
+	label[0] = 0;
+	options[0] = 0;
 	x = y = type = min = max = 0;
 	enabled = visible = true;
 	changed = false;
@@ -35,7 +35,7 @@ Widget::Widget()
 	image = NULL;
 }
 
-void Widget::setProperties(char *name, char *groupName, char *label, char *options, int x, int y, int min, int max)
+void Widget::setProperties(const char *name, const char *groupName, const char *label, const char *options, int x, int y, int min, int max)
 {
 	if ((strlen(name) > 50) || (strlen(groupName) > 50) || (strlen(label) > 80) || (strlen(options) > 100))
 	{
@@ -43,10 +43,10 @@ void Widget::setProperties(char *name, char *groupName, char *label, char *optio
 		exit(1);
 	}
 
-	strcpy(this->name, name);
-	strcpy(this->groupName, groupName);
-	strcpy(this->label, label);
-	strcpy(this->options, options);
+	strlcpy(this->name, name, sizeof this->name);
+	strlcpy(this->groupName, groupName, sizeof this->groupName);
+	strlcpy(this->label, label, sizeof this->label);
+	strlcpy(this->options, options, sizeof this->options);
 	this->x = x;
 	this->y = y;
 	this->min = min;
