@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -73,7 +73,7 @@ void aquaBossRecharge()
 		{
 			if (enemy->health > -100)
 			{
-				enemy->dx = enemy->dx = 0;
+				enemy->dx = enemy->dy = 0;
 				enemy->health = -1;
 				if (enemy->health % 10)
 				{
@@ -287,7 +287,7 @@ void aquaBossMainInit()
 	debug(("aquaBossMainInit\n"));
 	
 	map.boss[0] = new Boss();
-	strcpy(map.boss[0]->name, "BioMech Aqua Blob");
+	strlcpy(map.boss[0]->name, "BioMech Aqua Blob", sizeof map.boss[0]->name);
 	map.boss[0]->health = 45 * game.skill;
 	map.boss[0]->maxHealth = 45 * game.skill;
 	map.boss[0]->setSprites(graphics.getSprite("AquaBossRight", true), graphics.getSprite("AquaBossLeft", true), graphics.getSprite("AquaBossLeft", true));
