@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -359,6 +359,12 @@ enum {
 #ifndef GAMEPLAYMANUAL
 	#define GAMEPLAYMANUAL "manual.html"
 #endif
+#ifndef MEDAL_SERVER_HOST
+	#define MEDAL_SERVER_HOST "localhost"
+#endif
+#ifndef MEDAL_SERVER_PORT
+	#define MEDAL_SERVER_PORT 80
+#endif
 
 enum {
 
@@ -366,15 +372,16 @@ enum {
 	PAK_SOUND,
 	PAK_MUSIC,
 	PAK_DATA,
-	PAK_FONT
+	PAK_FONT,
+	PAK_TAGS
 };
 
 /* ############# debug ################## */
 
-#if USEPAK
-	#define debug(x) {}
-#else
+#if DEBUG
 	#define debug(x) {printf("*** DEBUG: "); printf x;}
+#else
+	#define debug(x) {}
 #endif
 
 #ifndef IGNORE_FLAGTOKEN_ERRORS
