@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -268,9 +268,8 @@ void doAI(Entity *enemy)
 	// Don't enter areas you're not supposed to
 	if (enemy->tx != (int)enemy->x)
 	{
-		if (!(enemy->flags & ENT_FLIES))
+		if (!(enemy->flags & (ENT_FLIES|ENT_SWIMS)))
 		{
-			//if ((map.data[x][y] == MAP_AIR) || (map.data[x][y] >= MAP_DECORATION))
 			if (!map.isSolid(x, y))
 			{
 				enemy->tx = (int)enemy->x;
@@ -344,6 +343,18 @@ void doAI(Entity *enemy)
 	lookForPlayer(enemy);
 }
 
+void checkCombo()
+{
+	int old = game.currentComboHits;
+	
+	game.doCombo();
+	
+	if (old == 24 && game.currentComboHits == 25)
+	{
+		presentPlayerMedal("25_Hit_Combo");
+	}
+}
+
 void enemyBulletCollisions(Entity *bullet)
 {
 	if (bullet->health < 1)
@@ -366,8 +377,6 @@ void enemyBulletCollisions(Entity *bullet)
 
 		if ((bullet->owner == &player) || (bullet->owner == &engine.world) || (bullet->flags & ENT_BOSS))
 		{
-			sprintf(comboString, "Combo-%s", bullet->name);
-
 			if (Collision::collision(enemy, bullet))
 			{
 				if (bullet->id != WP_LASER)
@@ -439,14 +448,15 @@ void enemyBulletCollisions(Entity *bullet)
 					{	
 						if (bullet->owner == &player)
 						{
-							game.score += enemy->value;
+							addPlayerScore(enemy->value);
 							game.currentMissionEnemiesDefeated++;
 	
 							if (player.currentWeapon != &weapon[WP_LASER])
 							{
-								game.doCombo();
+								checkCombo();
 							}
 							
+							snprintf(comboString, sizeof comboString, "Combo-%s", bullet->name);
 							checkObjectives(comboString, false);
 							checkObjectives("Enemy", false);
 							checkObjectives(enemy->name, false);
@@ -494,7 +504,8 @@ void enemyBulletCollisions(Entity *bullet)
 					{
 						if (player.currentWeapon != &weapon[WP_LASER])
 						{
-							game.doCombo();
+							snprintf(comboString, sizeof comboString, "Combo-%s", bullet->name);
+							checkCombo();
 							checkObjectives(comboString, false);
 						}
 					}
@@ -503,7 +514,7 @@ void enemyBulletCollisions(Entity *bullet)
 				if (game.currentComboHits >= 3)
 				{
 					char message[50];
-					sprintf(message, _("%d Hit Combo!"), game.currentComboHits);
+					snprintf(message, sizeof message, _("%d Hit Combo!"), game.currentComboHits);
 					engine.setInfoMessage(message, 0, INFO_NORMAL);
 				}
 
@@ -837,7 +848,7 @@ void loadDefEnemies()
 {
 	for (int i = 0 ; i < MAX_ENEMIES ; i++)
 	{
-		strcpy(defEnemy[i].name, "");
+		defEnemy[i].name[0] = 0;
 	}
 
 	int enemy = 0;
