@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -34,6 +34,8 @@ extern void addSmokeAndFire(Entity *ent, float dx, float dy, int amount);
 extern void checkObjectives(const char *name, bool alwaysInform);
 extern Weapon *getWeaponByName(const char *name);
 extern void addFireTrailParticle(float x, float y);
+extern void addPlayerScore(int score);
+extern void presentPlayerMedal(const char *tname);
 
 extern void doGaldovAI(Entity *galdov);
 extern void addTeleportParticles(float x, float y, int amount, int soundToPlay);
