@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -90,7 +90,7 @@ void addExplosion(float x, float y, int radius, Entity *owner)
 				
 				if (owner == &player)
 				{
-					game.score += enemy->value;
+					addPlayerScore(enemy->value);
 				}
 			}
 			
