@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -147,7 +147,7 @@ void galdovInitBlackDroids()
 			map.boss[i] = new Boss();
 		}
 		debug(("BlackDroid %d init\n", i));
-		strcpy(map.boss[i]->name, "BlackDrod");
+		strlcpy(map.boss[i]->name, "BlackDrod", sizeof map.boss[i]->name);
 		map.boss[i]->health = -90;
 		map.boss[i]->maxHealth = -90;
 		map.boss[i]->setSprites(graphics.getSprite("BlackDroidRight", true), graphics.getSprite("BlackDroidLeft", true), graphics.getSprite("BlackDroidDie", true));
@@ -230,6 +230,7 @@ void galdovFinalDie()
 		self->react = NULL;
 		Math::removeBit(&self->flags, ENT_FLIES);
 		Math::removeBit(&self->flags, ENT_FIRETRAIL);
+		presentPlayerMedal("Final_Battle");
 	}
 	
 	self->setActionFinished(1);
@@ -492,7 +493,7 @@ void galdovFinalSplit()
 		if (map.boss[i] == NULL)
 		{
 			map.boss[i] = new Boss();
-			strcpy(map.boss[i]->name, "MiniGaldov");
+			strlcpy(map.boss[i]->name, "MiniGaldov", sizeof map.boss[i]->name);
 			map.boss[i]->health = 10 * game.skill;
 			map.boss[i]->maxHealth = 10 * game.skill;
 		}
@@ -555,7 +556,7 @@ void galdovFinalInit()
 	debug(("galdovFinalInit\n"));
 	
 	map.boss[0] = new Boss();
-	strcpy(map.boss[0]->name, "Galdov");
+	strlcpy(map.boss[0]->name, "Galdov", sizeof map.boss[0]->name);
 	map.boss[0]->health = 45 * game.skill;
 	map.boss[0]->maxHealth = 45 * game.skill;
 	map.boss[0]->setSprites(graphics.getSprite("GaldovRight", true), graphics.getSprite("GaldovLeft", true), graphics.getSprite("GaldovDie", true));
@@ -573,9 +574,9 @@ void galdovFinalInit()
 	map.boss[0]->die = &galdovFinalDie;
 	Math::addBit(&map.boss[0]->flags, ENT_AIMS);
 	
-	audio.loadSound(SND_BOSSCUSTOM1, "sound/galdovSplit.wav");
-	audio.loadSound(SND_BOSSCUSTOM2, "sound/galdovPain.wav");
-	audio.loadSound(SND_BOSSCUSTOM3, "sound/galdovDie.wav");
+	audio.loadSound(SND_BOSSCUSTOM1, "sound/galdovSplit");
+	audio.loadSound(SND_BOSSCUSTOM2, "sound/galdovPain");
+	audio.loadSound(SND_BOSSCUSTOM3, "sound/galdovDie");
 	
 	map.setMainBossPart(map.boss[0]);
 	
@@ -679,7 +680,7 @@ void galdovFinalShieldInit()
 			delete map.boss[i];
 		}
 		map.boss[i] = new Boss();
-		strcpy(map.boss[i]->name, "OrbBomb");
+		strlcpy(map.boss[i]->name, "OrbBomb", sizeof map.boss[i]->name);
 		map.boss[i]->setSprites(graphics.getSprite("DroidOrb", true), graphics.getSprite("DroidOrb", true), graphics.getSprite("DroidOrb", true));
 		map.boss[i]->health = 999999;
 		map.boss[i]->maxHealth = 99999;
