@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -296,6 +296,7 @@ int gameover()
 	}
 
 	SDL_Surface *gameover = graphics.quickSprite("Game Over", graphics.loadImage("gfx/main/gameover.png"));
+	graphics.setTransparent(gameover);
 
 	audio.loadGameOverMusic();
 	audio.playMusic();
@@ -315,7 +316,9 @@ int gameover()
 	if (game.canContinue > 1)
 	{
 		Widget *widget = engine.getWidgetByName("gameOverNo");
-		sprintf(widget->label, "%s (%d)", widget->label, game.canContinue);
+		char postfix[100];
+		snprintf(postfix, sizeof postfix, " (%d)", game.canContinue);
+		strlcat(widget->label, postfix, sizeof widget->label);
 	}
 
 	while (true)
@@ -387,7 +390,7 @@ void showMissionInformation()
 
 	graphics.drawRect(1, 1, 398, 298, graphics.black, graphics.white, panelBack);
 
-	char message[100];
+	char message[256];
 	int col1 = 25;
 	int col2 = 375;
 	int y = 30;
@@ -407,13 +410,13 @@ void showMissionInformation()
 	if (map.totalMIAs > 0)
 	{
 		graphics.setFontColor(0xff, 0xff, 0xff, 0x00, 0x00, 0x00);
-		sprintf(message, _("Rescue %d MIAs"), map.requiredMIAs);
+		snprintf(message, sizeof message, _("Rescue %d MIAs"), map.requiredMIAs);
 		graphics.drawString(message, col1, y, TXT_LEFT, panel);
 
 		if (map.foundMIAs < map.requiredMIAs)
 		{
 			graphics.setFontColor(0xff, 0x00, 0x00, 0x00, 0x00, 0x00);
-			sprintf(message, "%d / %d", map.foundMIAs, map.requiredMIAs);
+			snprintf(message, sizeof message, "%d / %d", map.foundMIAs, map.requiredMIAs);
 			graphics.drawString(message, col2, y, TXT_RIGHT, panel);
 		}
 		else
@@ -457,7 +460,7 @@ void showMissionInformation()
 			}
 			else
 			{
-				sprintf(message, "%d / %d", objective->currentValue, objective->targetValue);
+				snprintf(message, sizeof message, "%d / %d", objective->currentValue, objective->targetValue);
 				graphics.drawString(message, col2, y, TXT_RIGHT, panel);
 			}
 		}
@@ -471,7 +474,7 @@ void showMissionInformation()
 	if (game.skill == 3)
 	{
 		graphics.setFontColor(0xff, 0xff, 0x00, 0x00, 0x00, 0x00);
-		sprintf(message, _("Time Limit - %d:%.2d Minutes"), map.remainingMinutes, map.remainingSeconds);
+		snprintf(message, sizeof message, _("Time Limit - %d:%.2d Minutes"), map.remainingMinutes, map.remainingSeconds);
 		graphics.drawString(message, 200, 260, TXT_CENTERED, panel);
 	}
 	
@@ -566,12 +569,13 @@ int doGame()
 	SDL_FillRect(graphics.screen, NULL, graphics.black);
 	graphics.delay(1000);
 
-	Uint32 then, frames, frameLimit, millis, frameCounter;
+	Uint32 then, frames, frameLimit, millis;
+	Uint32 start, cur;
 
-	#if !USEPAK
-	Uint32 now;
+	#if DEBUG
+	Uint32 now, frameCounter;
 	char fps[10];
-	strcpy(fps, "fps");
+	strlcpy(fps, "fps", sizeof fps);
 	#endif
 
 	engine.messageTime = -1;
@@ -584,12 +588,10 @@ int doGame()
 	{
 		player.health = -99;
 
-		//#if USEPAK
 		if ((!map.isBossMission) && (replayData.replayMode == REPLAY_MODE::NONE))
 		{
 			showMissionInformation();
 		}
-		//#endif
 
 		game.levelsStarted++;
 	}
@@ -616,8 +618,10 @@ int doGame()
 
 	frameLimit = SDL_GetTicks() + 16;
 	frames = millis = 0;
-	then = SDL_GetTicks();
+	start = then = SDL_GetTicks();
+#ifdef DEBUG
 	frameCounter = SDL_GetTicks();
+#endif
 
 	if ((strcmp(map.name, "Space Station") == 0) && (!game.continueFromCheckPoint))
 	{
@@ -641,6 +645,7 @@ int doGame()
 	{
 		++frames;
 		++millis;
+		cur = SDL_GetTicks();
 
 		if (game.missionOverReason != MIS_PLAYEROUT)
 		{
@@ -682,6 +687,7 @@ int doGame()
 
 		drawMapTopLayer();
 		doStatusBar();
+		doMusicInfo(cur - start);
 
 		if ((engine.keyState[SDLK_ESCAPE]) && (game.missionOver == 0))
 		{
@@ -807,10 +813,11 @@ int doGame()
 		if ((engine.keyState[SDLK_F3]) && (engine.cheatSkipLevel))
 		{
 			autoCompleteAllObjectives(true);
+			engine.keyState[SDLK_F3] = 0;
 			engine.setInfoMessage("Skipping Mission...", 2, INFO_OBJECTIVE);
 		}
 		
-		#if !USEPAK
+		#if DEBUG
 		if (engine.keyState[SDLK_F1])
 		{
 			autoCompleteAllObjectives(false);
@@ -837,13 +844,14 @@ int doGame()
 		if (game.missionOverReason == MIS_GAMECOMPLETE)
 			frameLimit = SDL_GetTicks() + 64;
 
-		#if !USEPAK
-		graphics.drawString(fps, 600, 30, true, graphics.screen);
+		#if DEBUG
+		static Graphics::SurfaceCache fpsCache;
+		graphics.drawString(fps, 600, 30, true, graphics.screen, fpsCache);
 
 		if (SDL_GetTicks() > frameCounter + 500)
 		{
 			now = SDL_GetTicks();
-			sprintf(fps, "%2.2f fps", ((double)frames*1000)/(now - then));
+			snprintf(fps, sizeof fps, "%2.2f fps", ((double)frames*1000)/(now - then));
 			then = frameCounter = SDL_GetTicks();
 			frames = 0;
 		}
@@ -868,7 +876,7 @@ int doGame()
 			if (strcmp(map.name, "Space Station"))
 			{
 				graphics.delay(1000);
-				audio.loadMusic("music/commando.xm");
+				audio.loadMusic("music/grasslands");
 				audio.playMusic();
 				graphics.fadeToBlack();
 				
