@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #endif
 #include <time.h>
 #include "headers.h"
+#include <SDL/SDL_thread.h>
 
 extern SDL_Surface *loadImage(const char *filename);
 
@@ -36,3 +37,4 @@ extern Game game;
 extern Graphics graphics;
 extern Map map;
 extern ReplayData replayData;
+extern MedalServer medalServer;
