@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -27,6 +27,8 @@ extern bool checkBrickContact(Entity *object);
 extern void moveEntity(Entity *ent);
 extern void checkObjectives(const char *name, bool alwaysInform);
 extern void addTeleportParticles(float x, float y, int amount, int soundToPlay);
+extern void addPlayerScore(int score);
+extern void presentPlayerMedal(const char *tname);
 
 extern Audio audio;
 extern Engine engine;
