@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -26,7 +26,7 @@ void showHelp()
 {
 	printf("\n");
 	printf("Blob Wars, Episode I - Metal Blob Solid (Version %.2f, Release %d)\n", VERSION, RELEASE);
-	printf("Copyright (C) 2004 Parallel Realities\n");
+	printf("Copyright (C) 2004-2011 Parallel Realities\n");
 	printf("Licensed under the GNU General Public License (GPL)\n\n");
 
 	printf("The Metal Blob Solid gameplay manual can be found in,\n");
@@ -56,7 +56,7 @@ void listMaps()
 {
 	printf("\n");
 	printf("Blob Wars, Episode I - Metal Blob Solid (Version %.2f, Release %d)\n", VERSION, RELEASE);
-	printf("Copyright (C) 2004 Parallel Realities\n");
+	printf("Copyright (C) 2004-2011 Parallel Realities\n");
 	printf("Licensed under the GNU General Public License (GPL)\n\n");
 	
 	printf("Available Maps\n");
@@ -92,9 +92,9 @@ void showVersion()
 {
 	printf("\n");
 	printf("Blob Wars, Episode I - Metal Blob Solid (Version %.2f, Release %d)\n", VERSION, RELEASE);
-	printf("Copyright (C) 2004 Parallel Realities\n");
+	printf("Copyright (C) 2004-2011 Parallel Realities\n");
 	printf("Licensed under the GNU General Public License (GPL)\n\n");
-	exit(0);
+// 	exit(0);
 }
 
 int main(int argc, char *argv[])
@@ -102,6 +102,10 @@ int main(int argc, char *argv[])
 	#if !USEPAK
 	debug(("Not Using PAK...\n"));
 	#endif
+
+	#if RELEASE
+	chdir(PAKLOCATION);
+	#endif
 	
 	config.engine = &engine;
 	
@@ -126,17 +130,17 @@ int main(int argc, char *argv[])
 		else if (strcmp(argv[i], "-mono") == 0) engine.useAudio = 1;
 		else if (strcmp(argv[i], "-version") == 0) showVersion();
 		else if (strcmp(argv[i], "--help") == 0) showHelp();
-		else if (strcmp(argv[i], "-record") == 0) {recordMode = REPLAY_MODE::RECORD; strcpy(replayData.filename, argv[++i]);}
-		else if (strcmp(argv[i], "-playback") == 0) {recordMode = REPLAY_MODE::PLAYBACK; strcpy(replayData.filename, argv[++i]);}
+		else if (strcmp(argv[i], "-record") == 0) {recordMode = REPLAY_MODE::RECORD; strlcpy(replayData.filename, argv[++i], sizeof replayData.filename);}
+		else if (strcmp(argv[i], "-playback") == 0) {recordMode = REPLAY_MODE::PLAYBACK; strlcpy(replayData.filename, argv[++i], sizeof replayData.filename);}
 		else if (strcmp(argv[i], "-map") == 0) {game.setMapName(argv[++i]); requiredSection = SECTION_GAME;}
 		else if (strcmp(argv[i], "-listmaps") == 0) listMaps();
+		else if (strcmp(argv[i], "-credits") == 0) requiredSection = SECTION_CREDITS;
 		
-		#if !USEPAK
+		#if DEBUG
 		else if (strcmp(argv[i], "-showsprites") == 0) showSprites = true;
 		else if (strcmp(argv[i], "-hub") == 0) hub = true;
 		else if (strcmp(argv[i], "-randomscreens") == 0) graphics.takeRandomScreenShots = true;
 		else if (strcmp(argv[i], "-nomonsters") == 0) engine.devNoMonsters = true;
-		else if (strcmp(argv[i], "-credits") == 0) requiredSection = SECTION_CREDITS;
 		#endif
 	}
 	
@@ -148,7 +152,7 @@ int main(int argc, char *argv[])
 			
 		case REPLAY_MODE::RECORD:
 			requiredSection = SECTION_GAME;
-			strcpy(replayData.header.map, game.mapName);
+			strlcpy(replayData.header.map, game.mapName, sizeof replayData.header.map);
 			replayData.header.skill = game.skill = 3;
 			replayData.setMode(REPLAY_MODE::RECORD);
 			break;
