@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -51,7 +51,7 @@ void drawMap()
 			{
 				graphics.blit(graphics.tile[brick], r.x, r.y, graphics.screen, false);
 				
-				#if !USEPAK
+				#if DEBUG
 				if ((brick >= MAP_NORESET) && (brick < MAP_DECORATION))
 				{
 					graphics.drawRect(r.x, r.y, 32, 4, graphics.yellow, graphics.screen);
@@ -393,13 +393,15 @@ void showMap(int centerX, int centerY)
 	graphics.drawString(_("Enemies"), 430, 410, TXT_LEFT, graphics.screen);
 
 	graphics.setFontSize(1);
-	sprintf(string, "%s - %.2d:%.2d:%.2d", _("Mission Time"), game.currentMissionHours, game.currentMissionMinutes, game.currentMissionSeconds);
+	snprintf(string, sizeof string, "%s - %.2d:%.2d:%.2d", _("Mission Time"), game.currentMissionHours, game.currentMissionMinutes, game.currentMissionSeconds);
 	graphics.drawString(string, 320, 60, TXT_CENTERED, graphics.screen);
 	graphics.drawString(_("Press Button to Continue..."), 320, 450, TXT_CENTERED, graphics.screen);
 
 	engine.flushInput();
 	engine.clearInput();
 
+	doMusicInfo(-1);
+
 	while (true)
 	{
 		engine.getInput();
@@ -647,7 +649,7 @@ void parseMapDataLine(const char *line, int y)
 
 		while (true)
 		{
-			*line++;
+			line++;
 
 			if (*line == ' ')
 				break;
