@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -22,8 +22,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 void loadSound(int index, const char *filename)
 {
-	if (!audio.loadSound(index, filename))
-		graphics.showErrorAndExit(ERR_FILE, filename);
+	audio.loadSound(index, filename);
 
 	graphics.showLoading(1, 30);
 }
@@ -99,48 +98,48 @@ void loadResources()
 		graphics.showLoading(1, 20);
 	}
 
-	loadSound(SND_WATERIN, "sound/waterIn.wav");
-	loadSound(SND_WATEROUT, "sound/waterOut.wav");
-	loadSound(SND_ITEM, "sound/item.wav");
-	loadSound(SND_PISTOL, "sound/pistol.wav");
-	loadSound(SND_RICO1, "sound/rico1.wav");
-	loadSound(SND_RICO2, "sound/rico2.wav");
-	loadSound(SND_MACHINEGUN, "sound/machinegun.wav");
-	loadSound(SND_DEATH1, "sound/death1.wav");
-	loadSound(SND_DEATH2, "sound/death2.wav");
-	loadSound(SND_DEATH3, "sound/death3.wav");
-	loadSound(SND_GRENADE, "sound/grenade.wav");
-	loadSound(SND_ROCKET, "sound/rocket.wav");
-	loadSound(SND_FIREBALL, "sound/fireball.wav");
-	loadSound(SND_HIT, "sound/punch.wav");
-	loadSound(SND_SPLAT, "sound/splat.wav");
-	loadSound(SND_POP, "sound/pop1.wav");
-	loadSound(SND_TELEPORT1, "sound/teleport1.wav");
-	loadSound(SND_TELEPORT2, "sound/teleport2.wav");
-	loadSound(SND_TELEPORT3, "sound/teleport3.wav");
-	loadSound(SND_GETWEAPON, "sound/weaponPickup.wav");
-	loadSound(SND_LASER, "sound/laser.wav");
-	loadSound(SND_ELECDEATH1, "sound/elecDeath1.wav");
-	loadSound(SND_ELECDEATH2, "sound/elecDeath2.wav");
-	loadSound(SND_ELECDEATH3, "sound/elecDeath3.wav");
-	loadSound(SND_LOCKEDDOOR, "sound/doorLocked.wav");
-	loadSound(SND_OPENDOOR, "sound/doorOpen.wav");
-	loadSound(SND_DOOROPENED, "sound/doorOpened.wav");
-	loadSound(SND_SWITCH1, "sound/switch.wav");
-	loadSound(SND_SWITCH2, "sound/switch.wav");
-	loadSound(SND_DROWNING, "sound/drowning.wav");
-	loadSound(SND_GULP, "sound/gulp.wav");
-	loadSound(SND_EAT, "sound/eat.wav");
-	loadSound(SND_THROW, "sound/throw.wav");
-	loadSound(SND_GRBOUNCE, "sound/grenadeBounce.wav");
-	loadSound(SND_SPREADGUN, "sound/plasma.wav");
-	loadSound(SND_STONEBREAK, "sound/stoneBreak.wav");
-	loadSound(SND_ELECTRICITY1, "sound/electricity1.wav");
-	loadSound(SND_ELECTRICITY2, "sound/electricity2.wav");
-	loadSound(SND_ELECTRICITY3, "sound/electricity3.wav");
-	loadSound(SND_CLANG, "sound/clang.wav");
-	loadSound(SND_FIRECRACKLE, "sound/fireCrackle.wav");
-	loadSound(SND_CLOCK, "sound/clock.wav");
+	loadSound(SND_WATERIN, "sound/waterIn");
+	loadSound(SND_WATEROUT, "sound/waterOut");
+	loadSound(SND_ITEM, "sound/item");
+	loadSound(SND_PISTOL, "sound/pistol");
+	loadSound(SND_RICO1, "sound/rico1");
+	loadSound(SND_RICO2, "sound/rico2");
+	loadSound(SND_MACHINEGUN, "sound/machinegun");
+	loadSound(SND_DEATH1, "sound/death1");
+	loadSound(SND_DEATH2, "sound/death2");
+	loadSound(SND_DEATH3, "sound/death3");
+	loadSound(SND_GRENADE, "sound/grenade");
+	loadSound(SND_ROCKET, "sound/rocket");
+	loadSound(SND_FIREBALL, "sound/fireball");
+	loadSound(SND_HIT, "sound/punch");
+	loadSound(SND_SPLAT, "sound/splat");
+	loadSound(SND_POP, "sound/pop1");
+	loadSound(SND_TELEPORT1, "sound/teleport1");
+	loadSound(SND_TELEPORT2, "sound/teleport2");
+	loadSound(SND_TELEPORT3, "sound/teleport3");
+	loadSound(SND_GETWEAPON, "sound/weaponPickup");
+	loadSound(SND_LASER, "sound/laser");
+	loadSound(SND_ELECDEATH1, "sound/elecDeath1");
+	loadSound(SND_ELECDEATH2, "sound/elecDeath2");
+	loadSound(SND_ELECDEATH3, "sound/elecDeath3");
+	loadSound(SND_LOCKEDDOOR, "sound/doorLocked");
+	loadSound(SND_OPENDOOR, "sound/doorOpen");
+	loadSound(SND_DOOROPENED, "sound/doorOpened");
+	loadSound(SND_SWITCH1, "sound/switch");
+	loadSound(SND_SWITCH2, "sound/switch");
+	loadSound(SND_DROWNING, "sound/drowning");
+	loadSound(SND_GULP, "sound/gulp");
+	loadSound(SND_EAT, "sound/eat");
+	loadSound(SND_THROW, "sound/throw");
+	loadSound(SND_GRBOUNCE, "sound/grenadeBounce");
+	loadSound(SND_SPREADGUN, "sound/plasma");
+	loadSound(SND_STONEBREAK, "sound/stoneBreak");
+	loadSound(SND_ELECTRICITY1, "sound/electricity1");
+	loadSound(SND_ELECTRICITY2, "sound/electricity2");
+	loadSound(SND_ELECTRICITY3, "sound/electricity3");
+	loadSound(SND_CLANG, "sound/clang");
+	loadSound(SND_FIRECRACKLE, "sound/fireCrackle");
+	loadSound(SND_CLOCK, "sound/clock");
 
 	loadDefWeapons();
 
