@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004 Parallel Realities
+Copyright (C) 2004-2011 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -382,7 +382,7 @@ void tankBossMGInit()
 	debug(("tankBossMGInit\n"));
 	
 	map.boss[0] = new Boss();
-	strcpy(map.boss[0]->name, "BioMech Tank V1.1");
+	strlcpy(map.boss[0]->name, "BioMech Tank V1.1", sizeof map.boss[0]->name);
 	map.boss[0]->health = 65 * game.skill;
 	map.boss[0]->maxHealth = 65 * game.skill;
 	map.boss[0]->setSprites(graphics.getSprite("BlobTankCannonRight", true), graphics.getSprite("BlobTankCannonLeft", true), graphics.getSprite("BlobTankCannonLeft", true));
@@ -399,8 +399,8 @@ void tankBossMGInit()
 	map.boss[0]->die = &tankBossMGDie;
 	Math::addBit(&map.boss[0]->flags, ENT_AIMS);
 	
-	audio.loadSound(SND_BOSSCUSTOM1, "sound/tankBeam.wav");
-	audio.loadSound(SND_BOSSCUSTOM2, "sound/tankBeamFire.wav");
+	audio.loadSound(SND_BOSSCUSTOM1, "sound/tankBeam");
+	audio.loadSound(SND_BOSSCUSTOM2, "sound/tankBeamFire");
 	
 	map.setMainBossPart(map.boss[0]);
 	
@@ -604,7 +604,7 @@ void tankBossGLInit()
 	debug(("tankBossGLInit\n"));
 	
 	map.boss[1] = new Boss();
-	strcpy(map.boss[1]->name, "BioMech Tank V2.6");
+	strlcpy(map.boss[1]->name, "BioMech Tank V2.6", sizeof map.boss[1]->name);
 	map.boss[1]->health = 65 * game.skill;
 	map.boss[1]->maxHealth = 65 * game.skill;
 	map.boss[1]->setSprites(graphics.getSprite("BlobTankGrenadeRight", true), graphics.getSprite("BlobTankGrenadeLeft", true), graphics.getSprite("BlobTankGrenadeLeft", true));
